@@ -179,6 +179,9 @@
 #' # Print results
 #' print(ega.wmt)
 #'
+#' # Plot with colorblind friendly edges
+#' print(ega.wmt, edge.color = c("#0B64AD", "red"))
+#'
 #' # Estimate EGAtmfg
 #' ega.wmt.tmfg <- EGA(
 #'   data = wmt, model = "TMFG",
@@ -229,7 +232,7 @@
 #'
 #' @export
 # EGA ----
-# Updated 21.09.2024
+# Updated 13.08.2025
 EGA <- function (
     data, n = NULL,
     corr = c("auto", "cor_auto", "cosine", "pearson", "spearman"),
@@ -304,7 +307,8 @@ EGA <- function (
   unidimensional_ARGS <- list( # standard arguments
     data = data, n = n, corr = corr, na.data = na.data,
     model = model, uni.method = uni.method,
-    verbose = verbose, needs_usable = FALSE # skips usable data check
+    verbose = verbose, needs_usable = FALSE, # skips usable data check
+    ...
   )
 
   # `data` at this point will be data or correlation matrix
