@@ -331,7 +331,7 @@
 #' @export
 #'
 # Bootstrap EGA ----
-# Updated 30.01.2025
+# Updated 24.04.2025
 bootEGA <- function(
     data, n = NULL,
     corr = c("auto", "cor_auto", "cosine", "pearson", "spearman"),
@@ -625,7 +625,7 @@ bootEGA <- function(
   if(plot.itemStability){
 
     # Plot results
-    plot(results, ...)
+    silent_plot(plot(results, ...))
 
   }
 
@@ -977,7 +977,7 @@ summary.bootEGA <- function(object, ...)
 
 #' @exportS3Method
 # S3 Plot Method ----
-# Updated 16.03.2025
+# Updated 24.04.2025
 plot.bootEGA <- function(x, ...)
 {
 
@@ -1051,14 +1051,13 @@ plot.bootEGA <- function(x, ...)
     )
 
   # Plot with item stability
-  arranged <- ggpubr::ggarrange(
-    ega_plot, plot(x$stability$item.stability, ...),
-    nrow = 1, ncol = 2
+  silent_call(
+    ggpubr::ggarrange(
+      ega_plot, plot(x$stability$item.stability, ...),
+      nrow = 1, ncol = 2
+    )
   )
 
-  # Make sure it plots
-  silent_plot(arranged)
-
 }
 
 #' @noRd
